# hey Emacs, its -*- rpm-spec -*-
# vim: set ft=spec fdm=marker :

# {{{ Defines
%define name ruby1.9
%define base_name ruby
%define version 1.9.0
%define release 1
%define svn 20080428
%define subver %(echo %version |cut -d. -f1,2)
%define rubylibdir %_datadir/%base_name/%version
%define archdir %_libdir/%base_name/%version/%_target_cpu-%_target_os
%define vendordir %_datadir/%base_name/vendor_ruby/%version
%define vendorarchdir %_libdir/%base_name/vendor_ruby/%version/%_target_cpu-%_target_os
%define rubyincludedir %_includedir/%base_name-%version
%define ruby_ri_systemdir %_datadir/ri/%version

%def_without emacs

%set_verify_elf_method fhs=normal
# }}}

# {{{ General
Packager: Ruby Maintainers Team <ruby@packages.altlinux.org>

BuildRequires: emacs-common groff-base libdb4-devel libgdbm-devel libncurses-devel libreadline-devel libssl-devel tk-devel zlib-devel
BuildRequires: ruby ruby-module-erb ruby-module-optparse

Name: %name
Version: %version
Release: alt%release.%svn
Summary: Interpreter of object-oriented scripting language Ruby %subver
License: Dual: GPL and Ruby
Url: http://www.ruby-lang.org/
Group: Development/Ruby

Requires: lib%name = %version-%release

Source: %base_name-%version-%release.tar
# }}}

# {{{ Description
%description
Ruby is the interpreted scripting language for quick and easy
object-oriented programming. It has many features to process text
files and to do system management tasks (as in perl). It is simple,
straight-forward, and extensible.
Interpreter of object-oriented scripting language Ruby %subver.
# }}}

# Subpackages {{{

# {{{ lib%name
%package -n lib%name
Summary: Libraries necessary to run the Ruby %subver
Group: System/Libraries
Provides: %archdir
Provides: %rubylibdir
Provides: %vendorarchdir
Provides: %vendordir

%description -n lib%name
Ruby is the interpreted scripting language for quick and easy
object-oriented programming. It has many features to process text
files and to do system management tasks (as in perl). It is simple,
straight-forward, and extensible.
This package includes the libruby, necessary to run Ruby %subver.
# }}}

# {{{ lib%name-devel
%package -n lib%name-devel
Summary: Header files for compiling extension modules for the Ruby %subver
Group: Development/Ruby
Requires: lib%name = %version-%release

%description -n lib%name-devel
Ruby is the interpreted scripting language for quick and easy
object-oriented programming. It has many features to process text
files and to do system management tasks (as in perl). It is simple,
straight-forward, and extensible.
This package contains the header files, necessary to make extension
library for Ruby %subver.
# }}}

# {{{ lib%name-devel-static
%package -n lib%name-devel-static
Summary: Statically linked Ruby %subver library
Group: Development/Ruby
Requires: lib%name-devel = %version-%release

%description -n lib%name-devel-static
Ruby is the interpreted scripting language for quick and easy
object-oriented programming. It has many features to process text
files and to do system management tasks (as in perl). It is simple,
straight-forward, and extensible.
This package includes statically linked Ruby %subver library needed for 
embedding Ruby in other applications.
# }}}

# {{{ %name-doc-examples
%package -n %name-doc-examples
Summary: This package provides example programs about Ruby %subver
Group: Development/Ruby
Requires: lib%name = %version-%release 

%description -n %name-doc-examples
Ruby is the interpreted scripting language for quick and easy
object-oriented programming. It has many features to process text
files and to do system management tasks (as in perl). It is simple,
straight-forward, and extensible.
# }}}

# {{{ %name-doc-ri
%package -n %name-doc-ri
Summary: This package provides ri documentation for Ruby %subver
Group: Development/Ruby
Requires: lib%name = %version-%release 
Requires: %name-modules = %version-%release

%description -n %name-doc-ri
This package provides ri documentation for Ruby %subver
# }}}

# {{{ %name-misc-elisp
%if_with emacs
%package -n %name-misc-elisp
Summary: ruby-mode for Emacsen
Group: Development/Ruby
Provides: emacs-ruby-mode
Requires: emacs-common

%description -n %name-misc-elisp
This package provides major-mode for editing Ruby scripts and some
emacs-lisp programs for Ruby programmers.
%endif
# }}}

# {{{ %name-modules
%package -n %name-modules
Summary: Ruby standard modules and utilities
Group: Development/Ruby
Requires: lib%name = %version-%release 

%description -n %name-modules
Ruby is the interpreted scripting language for quick and easy
object-oriented programming. It has many features to process text
files and to do system management tasks (as in perl). It is simple,
straight-forward, and extensible.
This package contains standard modules and utilities for Ruby %subver.
# }}}

# {{{ %name-tk
%package -n %name-tk
Summary: Ruby/Tk bindings
Group: Development/Ruby
Requires: lib%name = %version-%release 
Requires: %name-modules = %version-%release 

%description -n %name-tk
Ruby is the interpreted scripting language for quick and easy
object-oriented programming. It has many features to process text
files and to do system management tasks (as in perl). It is simple,
straight-forward, and extensible.
This pachage contains Tk bindings for Ruby %subver.
# }}}

# }}} Subpackges

# {{{ Prep
%prep
%setup -q -n %base_name-%version-%release
# }}}

# {{{ Build
%build

# {{{ Configure
%__autoconf

LDSHARED='gcc -shared' %configure \
          --program-suffix=%subver \
          --enable-frame-address \
          --with-libprefix=%_datadir/ruby \
          --with-sitedir=%_prefix/local/share/ruby/site_ruby \
          --with-sitearchdir=%_prefix/local/%_lib/ruby/site_ruby \
          --with-default-kcode=none \
          --enable-shared \
          --enable-ipv6 \
          --with-lookup-order-hack=INET \
         --disable-rpath \
         --enable-pthread
# }}}

# Hack to pass mkmf checks for socket as it tries to run tests in extensions
# linked against libruby.so which isn't in a LD's path yet
export LD_LIBRARY_PATH=%_builddir/ruby

# SMP-incompatible 
%make
#make test
%make rdoc

# {{{ ruby-elisp
%if_with emacs
for i in misc/*.el ; do
    emacs -batch --eval "(progn
            (setq load-path (append (list \".\") load-path))
            (byte-compile-file \"$i\"))"
done
%endif
# }}}
# }}}

# {{{ Install
%install
%makeinstall DESTDIR=%buildroot
%make DESTDIR=%buildroot  do-install-doc

%__mkdir %buildroot/bin
%__mkdir %buildroot/%_lib
%__mv %buildroot%_bindir/%name %buildroot/bin/%name
%__ln_s /bin/%name  %buildroot%_bindir/%name 
%__ln_s -f ../../%_lib/lib%name.so.%version %buildroot%_libdir/lib%name.so
%__mv %buildroot%_libdir/lib%name.so.%subver %buildroot/%_lib/lib%name.so.%subver
%__mv %buildroot%_libdir/lib%name.so.%version %buildroot/%_lib/lib%name.so.%version

%__mkdir_p %buildroot%_menudir/

for man in %buildroot%_man1dir/*.1; do 
dest="$(echo $man|sed 's|.1$|%subver.1|')"
mv $man $dest
done
%__install -m 644 irb.menu %buildroot%_menudir/irb%subver.menu

%__mkdir_p %buildroot%vendordir
%__mkdir_p %buildroot%vendorarchdir

# {{{ ruby-elisp
%if_with emacs
%__mkdir_p %buildroot/etc/emacs/site-start.d/
%__mkdir_p %buildroot%_emacslispdir/
%__install -m 644 ruby.el %buildroot/etc/emacs/site-start.d/
%__install -m 644 misc/*.el* %buildroot%_emacslispdir/
%endif
# }}}
  
# This is a hack but we really don't need to bytecompile 
# Python comparison sample in the Ruby manual
unset RPM_PYTHON
# }}}

# {{{ Files

# {{{ %name
%files
%doc ChangeLog* COPYING* LEGAL README* ToDo 
/bin/%name
%_bindir/%name
%_man1dir/%{name}*
# }}}

# {{{ lib%name
%files -n lib%name
/%_lib/lib%name.so.%subver
/%_lib/lib%name.so.%version
%archdir/rbconfig.rb
%archdir/enc
%dir %archdir
%dir %rubylibdir
%dir %vendorarchdir
%dir %vendordir
# }}}

# {{{ lib%name-devel
%files -n lib%name-devel
%_libdir/lib%name.so
%rubyincludedir/
# }}}

# {{{ lib%name-devel-static
%files -n lib%name-devel-static
%_libdir/lib%name-static.a
# }}}

# {{{ %name-doc-examples
#%files -n %name-doc-examples
#FIXME
# }}}

# {{{ %name-doc-ri
%files -n %name-doc-ri
%ruby_ri_systemdir
# }}}

# {{{ %name-misc-elisp
%if_with emacs
%files -n %name-misc-elisp
%_emacslispdir/*.el*
%_sysconfdir/emacs/site-start.d/ruby.el
%endif
# }}}

# {{{ %name-modules
%files -n %name-modules
%_bindir/*
%rubylibdir/*
%archdir/*
%_man1dir/*
%_menudir/*
%exclude %_bindir/%name
%exclude %_man1dir/%{name}*
%exclude %archdir/enc
%exclude %archdir/rbconfig.rb
%exclude %archdir/tcltklib.so
%exclude %archdir/tkutil.so
%exclude %rubylibdir/multi-tk.rb
%exclude %rubylibdir/remote-tk.rb
%exclude %rubylibdir/tcltk.rb
%exclude %rubylibdir/tk
%exclude %rubylibdir/tkextlib
%exclude %rubylibdir/tk*.rb
# }}}

# {{{ %name-module-tk
%files -n %name-tk
%archdir/tkutil.so
%archdir/tcltklib.so
%rubylibdir/tk
%rubylibdir/tkextlib
%rubylibdir/remote-tk.rb
%rubylibdir/multi-tk.rb
%rubylibdir/tk*.rb
%rubylibdir/tcltk.rb
%doc ext/tk/MANUAL*
%doc ext/tk/README*
%doc ext/tk/sample
# }}}

# }}} Files

# {{{ Pre/Post scripts
%post -n lib%name
%post_ldconfig

%postun -n lib%name
%postun_ldconfig

%post -n %name-modules
%update_menus

%postun -n  %name-modules
%clean_menus
# }}}

# {{{ Changelog
%changelog
* Mon Apr 28 2008 Kirill A. Shutemov <kas@altlinux.ru> 1.9.0-alt1.20080428
- First build of Ruby 1.9 for ALT Linux
  + for experements only ;)
- FHS patch rewritten
- Resplit subpackages
- No autoprovides/requires for now

* Fri Jan 11 2008 Kirill A. Shutemov <kas@altlinux.ru> 1.8.6-alt3
- branch based git repository 
- update to ruby_1_8_6 svn branch (revision 14091)
- sync with debian 1.8.6.111-2
  + CVE-2007-5162
- install libruby.so into %_libdir (bug #13951)
- move arch-depended site_ruby to /usr/local/ (raorn@)
- update macros (bug #13933)
- add missing deps to ruby-module-rexml

* Wed Apr 11 2007 Kirill A. Shutemov <kas@altlinux.ru> 1.8.6-alt2
- generation rdoc documentation:
  + add make rdoc

* Sun Apr 01 2007 Kirill A. Shutemov <kas@altlinux.ru> 1.8.6-alt1
- build without debug

* Sun Mar 25 2007 Kirill A. Shutemov <kas@altlinux.ru> 1.8.6-alt0
- 1.8.6

* Thu Feb 22 2007 Pavlov Konstantin <thresh@altlinux.ru> 1.8.5-alt4.1
- added rpm-build-ruby subpackage, moved rpm macros to it.

* Thu Jan 11 2007 Kirill A. Shutemov <kas@altlinux.ru> 1.8.5-alt4
- /usr/inculde/ruby added to libruby-devel(bug #10506)

* Fri Jan 05 2007 Sir Raorn <raorn@altlinux.ru> 1.8.5-alt3.1
- Do not handle html-style comments in code as specials

* Tue Dec 05 2006 Kirill A. Shutemov <kas@altlinux.ru> 1.8.5-alt3
- 1.8.5-p2
- ri pager selection fixing

* Tue Oct 24 2006 Sir Raorn <raorn@altlinux.ru> 1.8.5-alt2.1
- Re-added ruby-stdlibs - pure virtual package with all requires
- mkmf.rb moved to libruby-devel
- base64.rb moved to module-digest
- pstore.rb moved to module-fileutils
- module-stdlibs renamed to module-misc
- libruby-devel requires tool-rdoc
- Hardened requires on libruby for module-*
- Re-added lost %%ruby_configure macro
- Added macroses for "setup.rb"-based modules
- Added %%ruby_vendor macro - ruby -rvendor-specific

* Mon Oct 09 2006 Kirill A. Shutemov <kas@altlinux.ru> 1.8.5-alt2
- spec rewrite from scratch
- stdlibs sparate to many packages
- new packages naming strategy
- ruby executable moved to /bin
- ruby library moved to /%%_lib
- headers moved to /usr/include/ FHS
- and many others

* Tue Sep 26 2006 Kirill A. Shutemov <kas@altlinux.ru> 1.8.5-alt1
- 1.8.5
- debian 1.8.5-2 synced
- warnings in core removed

* Thu Apr 13 2006 Sir Raorn <raorn@altlinux.ru> 1.8.4-alt5
- Fixed x86_64 filelist and fhs patch (closes: #9401)
- rdocall script dropped

* Sat Mar 25 2006 ALT QA Team Robot <qa-robot@altlinux.org> 1.8.4-alt4.1
- Rebuilt with libdb4.4.

* Fri Mar 03 2006 Kirill A. Shutemov <kas@altlinux.ru> 1.8.4-alt4
- patching order changed
- Patch ported from FC ruby-1.8-fc-no-eaccess.patch:
    backported from ruby CVS to avoid conflict  between newer glibc.
- ruby-1.8-alt-ri-DESTDIR.patch removed

* Fri Mar 03 2006 Kirill A. Shutemov <kas@altlinux.ru> 1.8.4-alt3
- Patches ported from debian:
  * ruby-1.8-deb-delegate.rb.patch
   - delegate.rb should use Kernel::raise for Thread.
     [ruby-dev:22681][ruby-dev:22684]
   - delegate.rb should not delegate singleton_method_added.
  * ruby-1.8-deb-.document.patch
   - rdoc processes net/* and some libraries.
  * ruby-1.8-deb-yaml_bignum.patch
   - YAML.dump/load cannot handle Bignum. [ruby-core:6159]
   - patch from Michael Ablassmeier	
  * ruby-1.8-deb-yaml_symbol.patch
   - YAML loading of quoted symbols is broken

* Mon Feb 27 2006 Kirill A. Shutemov <kas@altlinux.ru> 1.8.4-alt2
- FHS patch updated:
  * DESTDIR processing fixed
  * rbconfig back to archlibdir
- Generating system-wide documentation for ri using make

* Tue Feb 14 2006 Kirill A. Shutemov <kas@altlinux.ru> 1.8.4-alt1
- spec cleanups
- FHS patch updated: headers in /usr/include/ruby/%%subver 

* Mon Jan 23 2006 Sir Raorn <raorn@altlinux.ru> 1.8.4-alt0
- [1.8.4]

* Fri Dec 30 2005 ALT QA Team Robot <qa-robot@altlinux.org> 1.8.2-alt7.1
- Rebuilt with libreadline.so.5.

* Wed Jun 08 2005 Kirill A. Shutemov <kas@altlinux.ru> 1.8.2-alt7
- rebuild

* Fri Apr 15 2005 Anton D. Kachalov <mouse@altlinux.org> 1.8.2-alt6.1
- multilib support

* Mon Feb 28 2005 Kirill A. Shutemov <kas@altlinux.ru> 1.8.2-alt6
- %%configure --with-vendordir
- Change default DESTDIR in rbconfig.rb

* Thu Feb 10 2005 ALT QA Team Robot <qa-robot@altlinux.org> 1.8.2-alt5.1.1
- Updated libdb4 build dependencies.
- Rebuilt with libdb4.3.

* Mon Jan 24 2005 Sir Raorn <raorn@altlinux.ru> 1.8.2-alt5.1
- Some spec cleanups
- Use --disable-rpath
- Use `%%_lib' instead of `lib' (maybe-x86_64-fixes)
- Do not set LD_LIBRARY_PATH - rubytest.rb does it for us
- Create created.rid file in RI site dir so it will look like doc dir
- Use rdoc -a by default

* Mon Jan 10 2005 Kirill A. Shutemov <kas@altlinux.ru> 1.8.2-alt5
- 1.8.2 release
- ruby-1.8.2-alt-extdoc.patch in upstream now

* Sun Sep 12 2004 Kirill A. Shutemov <kas@altlinux.ru> 1.8.2-alt4
- Move extensions docs from extensions/ext to extensions

* Sat Sep 11 2004 Sir Raorn <raorn@altlinux.ru> 1.8.2-alt3.2
- %%dir'ed ri_sitedir

* Sat Sep 11 2004 Sir Raorn <raorn@altlinux.ru> 1.8.2-alt3.1
- Changed %%ruby_ri_systemdir to %%ruby_ri_sitedir (points to
  %%_datadir/ri/%%subver/site)
- Document more external modules (which have it's own documentation):
  + iconv
  + io/wait
  + strscan
  + zlib

* Sun Sep 05 2004 Kirill A. Shutemov <kas@altlinux.ru> 1.8.2-alt3
- Add %%ruby_ri_systemdir and %%rdoc macros
- Now --ri-site defers DESTDIR (patch by Alexey I. Froloff)
- Add script 'rdocall' for generate all rdoc documentation

* Sat Aug 14 2004 Kirill A. Shutemov <kas@altlinux.ru> 1.8.2-alt2
- 1.8.2-preview2

* Sun Jul 18 2004 Kirill A. Shutemov <kas@altlinux.ru> 1.8.2-alt1
- 1.8.2-preview1
- New patch to fix 3506 by Sean Russell 

* Tue Jul 06 2004 Kirill A. Shutemov <kas@altlinux.ru> 1.8.1-alt9
- Add %%ruby_begin and %%ruby_end macros
- Add README.ALT-CP1251 and README.ALT-KOI8

* Mon May 10 2004 ALT QA Team Robot <qa-robot@altlinux.org> 1.8.1-alt8.1
- Rebuilt with openssl-0.9.7d.

* Tue Apr 20 2004 Kirill A. Shutemov <kas@altlinux.ru> 1.8.1-alt8
- Fixed bug #3506(REXML)

* Wed Mar 24 2004 Alexander Bokovoy <ab@altlinux.ru> 1.8.1-alt7
- Snapshot as of 2004/03/24
- Fixed:
    + socket extension build in chrooted environment

* Tue Mar 09 2004 Alexander Bokovoy <ab@altlinux.ru> 1.8.1-alt6
- Snapshot as of 2004/03/08

* Mon Feb 16 2004 Alexander Bokovoy <ab@altlinux.ru> 1.8.1-alt5
- Snapshot as of 2004/02/15
- Rebuild against libdb4.2

* Sun Dec 28 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8.1-alt4
- Snapshot as of 2003/12/28 of ruby_1_8 branch
- Removed:
    + patch for rdoc fixes (integrated to upstream)
- Fixed:
    + segfault in Syck's emitter (matz)

* Thu Dec 25 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8.1-alt3
- Fixed:
    + rdoc's simple markup ToFlow class
- We obsolete 'ri' package now but do not package rdoc-ed 
  'ri' metainfo for standard libs so far (nothing to package yet)

* Wed Dec 24 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8.1-alt2
- Fixed:
    + rdoc's simple markup classes

* Wed Dec 24 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8.1-alt1
- 1.8.1

* Thu Dec 18 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8-alt11
- Snapshot as of 2003/12/18
- REXML support for iconv(3) is in upstream now

* Sat Sep 27 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8-alt10
- Snapshot as of 2003/09/27
- All external documentation moved to ruby-doc-extra package

* Thu Aug 21 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8-alt9
- Snapshot as of 2003/08/21

* Wed Aug 06 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8-alt8
- Fixed:
  + REXML now falls back to iconv(3) when there is no native 
    support for specified encoding (ab)

* Tue Aug 05 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8-alt7
- Final Ruby 1.8.0 + post-release fixes from CVS

* Sat Aug 02 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8-alt6
- 2003/08/02
- OpenSSL support integrated, thus ruby-openssl is obsolete now

* Tue Jul 22 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8-alt5
- Snapshot as of 2003/07/22

* Mon Jul 07 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8-alt4
- Test::Unit is included into stdlibs, ruby-stdlibs package 
  obsoletes ruby-testunit now and provides it for backward 
  compatibility

* Sun Jul 06 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8-alt3
- Tag release in BTE
- Remove tinfo patch for curses, integrated into upstream

* Sat Jul 05 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8-alt2
- 1.8 CVS snapshot (2003/07/05)

* Sun Jun 29 2003 Alexander Bokovoy <ab@altlinux.ru> 1.8-alt1
- 1.8 CVS snapshot (2003/06/29)
- Patches updated, CGI patch excluded (already in upstream)
- Add %_libdir/%name/vendor_ruby/%subver/%{_target_cpu}-%{_host_os} to the list
  of owned directories for stdlibs-core
- Enhance dependencies between subpackages:
    + lib%name is a base package, everything else requires it (through a chain),
      it also owns a Ruby subtree directories
    + %name-stdlibs prerequires lib%name
    + %name-stdlibc-tk prerequires %name-stdlibs
    + every third-party Ruby package *should* prerequire lib%name
      if it is installable into Ruby subtree
- Clean up spec file:
    + Fix miniruby calls to use non-Perlish variable notation only
- Removed:
    + %name-stdlib-core package merged with lib%name
- Major review of packaged documentation:
    + Ruby FAQ is now in A4 PDF
    + Hal Fulton's "Rubyesque API" from EuRuKo03
    + Tobias Peters' "Garbage in Ruby Extensions" from EuRuKo03
    + Features of Ruby 1.8 since Ruby 1.6 from ruby-shim project

* Tue Dec 10 2002 Alexander Bokovoy <ab@altlinux.ru> 1.7.3-alt9
- Fixed:
    + Readline extension was lost due wrong check for libtermcap instead
      of libtinfo
    + fileutils.rb incorrect behaviour for symlinks (mouse@altlinux.ru)

* Fri Nov 22 2002 Alexander Bokovoy <ab@altlinux.ru> 1.7.3-alt8
- Fixed:
    + IRB code to not use #initialize publicly as it is a private method
      in Ruby 1.7 since 2002-11-14.
- Removed:
    + Proxy-Authorization support in Net::HTTP patch (integrated into upstream)

* Tue Nov 19 2002 Alexander Bokovoy <ab@altlinux.ru> 1.7.3-alt7
- Changed:
    + Installation splitted between %_datadir and %_libdir
      in order to be more conformant to FHS
    + Directory structure is stored in %name-stdlibs-core package
    + vendordir/vendorarchdir added as /usr/{lib,share}/ruby/vendor_ruby
      and site-specific dirs moved to /usr/local
- Fixed:
    + curses modules build fixed
    + mkmf.rb to successuly configure C++ exetnsions

* Tue Oct 29 2002 Alexander Bokovoy <ab@altlinux.ru> 1.7.3-alt6
- Removed:
    + misc/*.el as now they are part of (X)Emacs prog-modes
- Added:
    + Patch to fix CGI and Cookies to follow 1.7's split() behaviour
    + Gdbm module support
- Fixed:
    + Getaddrinfo detection code in mkmf
- ToDo:
    + Fix mkmf to run run_test() against locally compiled libruby.so
      when dealing with extensions, not against (non-)existent system-wide one

* Sat Oct 26 2002 Alexander Bokovoy <ab@altlinux.ru> 1.7.3-alt5
- News snapshot (2002/10/26)
- Fixed BuildReq to allow build of gdbm module
- Group changed to Development/Ruby
- Remove ruby-stdlibs-win32ole as it seems tend to not work

* Wed Oct 09 2002 Alexander Bokovoy <ab@altlinux.ru> 1.7.3-alt4
- New snapshot (2002/10/09)
- Changed:
    + Emacs support moved to %name-doc and placed in %_docdir/%name-%version/misc
      unless XEmacs and GNU Emacs maintaining teams decide where and how
      to put third-party program modes. Also, XEmacs already has (an outdated)
      ruby-mode.

* Thu Sep 26 2002 Sergey Bolshakov <s.bolshakov@belcaf.com> 1.7.3-alt3
- rebuilt with tcl 8.4

* Thu Sep 19 2002 Alexander Bokovoy <ab@altlinux.ru> 1.7.3-alt2
- New snapshot (2002/09/19)
- Added:
    + Patch to support proxy authorization in Net::HTTP (Alexander Bokovoy)
    + Win32ole support using Wine as ruby-stdlibs-win32ole
    + db module using libdb4
- Fixed:
    + Build requires to include Readline

* Mon Sep 09 2002 Alexander Bokovoy <ab@altlinux.ru> 1.7.3-alt1
- Initial build of 1.7.x
- Standard library splitted off to ruby-stdlibs
- More libification:
    + Dynamic library splitted off to libruby
    + ruby-devel renamed to libruby-devel
    + ruby-devel-static renamed to libruby-devel-static
- Tcl/Tk extensions work now and split off to ruby-stdlibs-tk
- Documentation extended

* Wed Aug  7 2002 Grigory Milev <week@altlinux.ru> 1.6.7-alt1
- minor spec cleanup

* Tue May 07 2002 Alexander Bokovoy <ab@altlinux.ru> 1.6.7-alt1
- 1.6.7 + post release fixes

* Fri Feb 08 2002 Alexander Bokovoy <ab@altlinux.ru> 1.6.6-alt3
- Dependencies for ruby-doc package refined

* Mon Jan 28 2002 Stanislav Ievlev <inger@altlinux.ru> 1.6.6-alt2
- rebuild with new python

* Wed Dec 26 2001 Alexander Bokovoy <ab@altlinux.ru> 1.6.6-alt1
- 1.6.6
- Removed:
    + mkmf patch (integrated into upstream)
    + Regexp patch (integrated into upstream)

* Thu Dec 20 2001 Alexander Bokovoy <ab@altlinux.ru> 1.6.5-alt6
- Fixed:
    + mkmf patch updated to one from Nobu Nakada

* Thu Dec 13 2001 Alexander Bokovoy <ab@altlinux.ru> 1.6.5-alt5
- Fixed:
    + Regexp UTF-8 handling (backport from 1.7.x)
    + %_libdir/ruby/site_ruby/%subver added

* Wed Dec 05 2001 Alexander Bokovoy <ab@altlinux.ru> 1.6.5-alt4
- Updated:
    + Programming Ruby up to 0.3a
    + URL for Ruby FAQ
- Fixed:
    + Programming Ruby html structure

* Fri Nov 30 2001 Alexander Bokovoy <ab@altlinux.ru> 1.6.5-alt3
- Fixed:
    + mkmf to allow full usage of $(DESTDIR), this is required to
      properly build extension packages

* Tue Oct 16 2001 Alexander Bokovoy <ab@altlinux.ru>   1.6.5-alt2
- Enable shared library build
- Move static library to devel-static

* Fri Sep 28 2001 Stanislav Ievlev <inger@altlinux.ru> 1.6.5-alt1
- 1.6.5

* Thu Jun 14 2001 Stanislav Ievlev <inger@altlinux.ru> 1.6.4-alt1
- 1.6.4

* Mon May 28 2001 Stanislav Ievlev <inger@altlinux.ru> 1.6.3-alt3
- New patches from Mandrake.

* Mon Apr 23 2001 Stanislav Ievlev <inger@altlinux.ru> 1.6.3-alt2
- Fix extentions. Thanks to Pixel.

* Wed Apr 18 2001 Stanislav Ievlev <inger@altlinux.ru> 1.6.3-alt1
- Up to 1.6.3

* Tue Jan 16 2001 AEN <aen@logic.ru>
- RE adaptations

* Mon Nov 27 2000 Pixel <pixel@mandrakesoft.com> 1.6.1-4mdk
- build again full optflags

* Wed Nov  8 2000 Pixel <pixel@mandrakesoft.com> 1.6.1-3mdk
- build without -fomit-frame-pointer for time being
- capitalize summaries

* Mon Oct  2 2000 Pixel <pixel@mandrakesoft.com> 1.6.1-2mdk
- fix mispelling

* Thu Sep 28 2000 Pixel <pixel@mandrakesoft.com> 1.6.1-1mdk
- new version
- remove "--with-default-kcode=none", not more needed
- remove setting optflags to -O2, ruby doesn't crashes any more

* Tue Sep 19 2000 Pixel <pixel@mandrakesoft.com> 1.6.0-1mdk
- new version

* Wed Aug 23 2000 Pixel <pixel@mandrakesoft.com> 1.4.6-6mdk
- add packager

* Tue Aug 22 2000 Pixel <pixel@mandrakesoft.com> 1.4.6-5mdk
- nicer site-start.d/ruby.el (use add-to-list)

* Tue Aug 22 2000 Pixel <pixel@mandrakesoft.com> 1.4.6-4mdk
- fix missing %%config

* Tue Aug 22 2000 Pixel <pixel@mandrakesoft.com> 1.4.6-3mdk
- use %_sysconfdir/emacs/site-start.d for the ruby-mode.el

* Fri Aug 18 2000 Pixel <pixel@mandrakesoft.com> 1.4.6-2mdk
- rebuild (fredlsux)

* Fri Aug 18 2000 Pixel <pixel@mandrakesoft.com> 1.4.6-1mdk
- new version
- remove menu

* Mon Aug 07 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.4.5-6mdk
- automatically added BuildRequires

* Wed Jul 19 2000 Pixel <pixel@mandrakesoft.com> 1.4.5-5mdk
- rebuild with clean clean_menus

* Wed Jul 19 2000 Pixel <pixel@mandrakesoft.com> 1.4.5-4mdk
- macroization
- BM

* Thu Jul 13 2000 Pixel <pixel@mandrakesoft.com> 1.4.5-3mdk
- fix %%URL

* Sun Jun 25 2000 Pixel <pixel@mandrakesoft.com> 1.4.5-2mdk
- rebuild (src.rpm got lost :( )

* Fri Jun 23 2000 Pixel <pixel@mandrakesoft.com> 1.4.5-1mdk
- new version

* Wed Jun 14 2000 Pixel <pixel@mandrakesoft.com> 1.4.4-1mdk
- new version

* Mon Apr 10 2000 Pixel <pixel@mandrakesoft.com> 1.4.3-6mdk
- fix group for doc

* Mon Mar 27 2000 Pixel <pixel@mandrakesoft.com> 1.4.3-5mdk
- add menu

* Sat Mar 25 2000 Pixel <pixel@mandrakesoft.com> 1.4.3-4mdk
- new group + cleanup

* Wed Feb 16 2000 Pixel <pixel@mandrakesoft.com> 1.4.3-3mdk
- build with no charset conversion (was kanji :)

* Mon Feb 14 2000 Pixel <pixel@mandrakesoft.com> 1.4.3-2mdk
- added the reference manual and FAQ in doc
- moved the lib/README in ext

* Mon Feb 14 2000 Pixel <pixel@mandrakesoft.com> 1.4.3-1mdk
- mandrake adaptation and spliting in -/doc/extensions

* Wed Dec 08 1999 Atsushi Yamagata <yamagata@plathome.co.jp>
- Updated to version 1.4.3

* Mon Sep 20 1999 Atsushi Yamagata <yamagata@plathome.co.jp>
- Updated to version 1.4.2 (Sep 18)

* Fri Sep 17 1999 Atsushi Yamagata <yamagata@plathome.co.jp>
- Updated to version 1.4.2

* Tue Aug 17 1999 Atsushi Yamagata <yamagata@plathome.co.jp>
- Updated to version 1.4.0

* Fri Jul 23 1999 Atsushi Yamagata <yamagata@plathome.co.jp>
- 2nd release
- Updated to version 1.2.6(15 Jul 1999)
- striped %prefix/bin/ruby

* Mon Jun 28 1999 Atsushi Yamagata <yamagata@plathome.co.jp>
- Updated to version 1.2.6(21 Jun 1999)

* Wed Apr 14 1999 Atsushi Yamagata <yamagata@plathome.co.jp>
- Updated to version 1.2.5

* Fri Apr 09 1999 Atsushi Yamagata <yamagata@plathome.co.jp>
- Updated to version 1.2.4

* Fri Dec 25 1998 Toru Hoshina <hoshina@best.com>
- Version up to 1.2 stable.

* Fri Nov 27 1998 Toru Hoshina <hoshina@best.com>
- Version up to 1.1c9.

* Thu Nov 19 1998 Toru Hoshina <hoshina@best.com>
- Version up to 1.1c8, however it appear short life :-P

* Fri Nov 13 1998 Toru Hoshina <hoshina@best.com>
- Version up.
# }}}
